/**
  *  \file client/tiles/csheader.h
  *  \brief WControlScreenHeaderTile tile
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_TILES_CSHEADER_H
#define PCC_V2_CLIENT_TILES_CSHEADER_H

#include "client/wtile.h"
#include "cpluslib/holder.h"
#include "resmgr/resmgr.h"
#include "game/obj.h"
#include "ui/commands.h"
#include "int/exec.h"
#include "client/wcolorframe.h"

// FIXME: can we get rid of this?
enum {
    cm_CS_Xchg = cm_ControlScreenFirst
};

class UIImageWidget;
class WColorFrame;

/*! \class WControlScreenHeaderTile
    \brief Header of a Control Screen

    Displays the top-most part of a control screen: name, description,
    picture, buttons. */
class WControlScreenHeaderTile : public WObjectTypeObserverTile {
    int buttons;
    ObjectHolder holder;
    UIImageWidget* image;
    WColorFrame* image_cf;
    WColorFrame* auto_cf;
    IntExecutionContext::ProcessKind pk;

    void init();
 public:
    WControlScreenHeaderTile(GObjectType& type, int buttons, IntExecutionContext::ProcessKind pk);
    void drawData(GfxCanvas& can);

    virtual string_t getTitle() = 0;
    virtual string_t getSubtitle() = 0;
    virtual ResId getPictureId() = 0;

    enum {
        bName  = 1,              // N
        bSend  = 2,              // I
        bAuto  = 4,              // Auto
        bCycle = 8,              // ,->
        bAdd   = 16,             // Add (Ins)
        bCScr  = 32,             // CScr (opposite of Auto)
        bJoin  = 64              // J (instead of cycle)
    };
};

#endif
