/**
  *  \file client/widgets/combatdiagram.h
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_WIDGETS_COMBATDIAGRAM_H
#define PCC_V2_CLIENT_WIDGETS_COMBATDIAGRAM_H

#include <vector>
#include "ui/ui.h"
#include "ui/widgets/tooltip.h"

class GClassicVcrDatabase;
class ProgressMonitor;

class WCombatDiagram {
 public:
    struct Item {
        bool planet;
        int id;
        int group_id;
        int sequence;
        int appears_in;
        Item(bool planet, int id, int group_id, int sequence, int appears_in)
            : planet(planet), id(id), group_id(group_id), sequence(sequence), appears_in(appears_in)
            { }
    };

    WCombatDiagram();
    void init(GClassicVcrDatabase& db, ProgressMonitor& prog);

    int getNumLines() const;
    const Item& getLine(int i) const;
    int findObjectLine(bool planet, int id) const;

 private:
    std::vector<Item> lines;
    std::vector<Item>::const_iterator findObject(bool planet, int id) const;
    void renameGroup(int from, int to);
};

class WCombatDiagramWidget : public UIWidget {
 public:
    WCombatDiagramWidget(const GClassicVcrDatabase& db, const WCombatDiagram& diag);

    void drawContent(GfxCanvas& can);
    void getLayoutInfo(LayoutInfo& info);
    bool handleEvent(const UIEvent& event, bool second_pass);
    void onStateChange(int state, bool enable);
    int getHoverSlot() const;

    bool getTeamColorState() const;
    void setTeamColorState(bool state);

    Signal0 sig_click_battle;

 private:
    const GClassicVcrDatabase& db;
    const WCombatDiagram& diag;
    int hover_slot;
    bool mdown;
    bool team_colors;
    UITooltipControl tt_ctl;
    bool tt_active;

    void setHoverSlot(int slot);
    GfxRect getSlotBoundingBox(int slot) const;
    string_t getObjectName(int line) const;
    int getColorForOwner(int owner) const;
};

#endif
