/**
  *  \file client/widgets/vcrinfohead.cc
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include <algorithm>
#include "client/widgets/vcrinfohead.h"
#include "game/racename.h"
#include "cpluslib/format.h"
#include "gfx/gfxcontext.h"
#include "game/vcrdb.h"
#include "io/io.h"
#include "util/recode.h"
#include "ui/util.h"
#include "resmgr/resid.h"
#include "resmgr/resmgr.h"

WVcrInfoHeader::WVcrInfoHeader(GClassicVcrDatabase& db, int slot, int side)
    : list(db, slot, side),
      image(105, 93)
{
    init();
}

WVcrInfoHeader::~WVcrInfoHeader()
{ }

void
WVcrInfoHeader::drawContent(GfxCanvas& can)
{
    const GfxRect& x = getExtent();
    const TVcr& v = list.getVcrEntry().getVcr();
    const int side = list.getSide();
    
    GfxContext ctx;
    ctx.useCanvas(can);
    ctx.useColorScheme(getSkin());
    ctx.setSolidBackground();
    ctx.setColor(UIColor::tc_Static);

    // Line 1
    ctx.useFont(*fonts[FONT_TITLE]);
    outTextF(ctx, x.x, x.y, x.w, convertGameToUtf8(getBasicString(v.objects[side].name)));

    // Line 2
    ctx.useFont(*fonts[FONT_NORMAL]);
    outTextF(ctx, x.x, x.y + font_heights[FONT_TITLE], x.w,
             format("(#%d, %s)", v.objects[side].id, player_racenames.getAdjName(v.objects[side].owner)));

    // Frame around list
    GfxRect list_size = list.getExtent();
    list_size.grow(1, 1);
    drawFrameDown(can, list_size);

    can.update(x);
}

void
WVcrInfoHeader::getLayoutInfo(LayoutInfo& li)
{
    // Height:
    //   FONT_TITLE       or  height of image + 2
    //   FONT_NORMAL
    //   height of list
    //   5
    // Width
    //   width of list + 2
    //   1 em
    //   width of image + 2

    // Get list size
    LayoutInfo list_size;
    list.getLayoutInfo(list_size);

    // FIXME: magic numbers
    li.pref_size.x = list_size.pref_size.x + font_ems[FONT_NORMAL] + 2 + 105 + 2;
    li.pref_size.y = std::max(font_heights[FONT_TITLE] + font_heights[FONT_NORMAL] + list_size.pref_size.y + 5, 95);
    li.min_size = li.pref_size;
    li.flags = 0;
}

void
WVcrInfoHeader::init()
{
    // Compute sizes
    LayoutInfo list_size;
    list.getLayoutInfo(list_size);

    LayoutInfo my_size;
    getLayoutInfo(my_size);

    // Place list in bottom-left corner
    GfxRect list_pos(0, 0, list_size.pref_size.x, list_size.pref_size.y);
    list_pos.moveToEdge(GfxRect(0, 0, my_size.pref_size.x, my_size.pref_size.y), 0, 2, 1);
    add(list, list_pos);

    // Place image next to list
    GfxRect image_pos(list_pos.x + list_pos.w + font_ems[FONT_NORMAL],
                      std::max(0, list_pos.y + list_pos.h - 92),
                      105, 93);
    add(image, image_pos);

    // Force redraw when list changes
    list.sig_moved.add(this, &WVcrInfoHeader::onMove);
}

void
WVcrInfoHeader::onMove()
{
    int pic = list.getCurrentPicture();
    int hull = list.getCurrentHull();
    ResId r;
    if (pic != 0) {
        if (hull != 0) {
            r = ResId(res::ship, pic, hull);
        } else {
            r = ResId(res::ship, pic);
        }
    } else if (list.getVcrEntry().isPlanet(list.getSide())) {
        r = ResId(res::planet);
    } else {
        r = ResId(res::ship);
    }
    image.setImage(requestPixmap(r));
    
    drawWidget();
}
