/**
  *  \file game/unpack.h
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_UNPACK_H
#define PCC_V2_GAME_UNPACK_H

#include "cpluslib/types.h"
#include "game/gen.h"
#include "game/sweep.h"
#include "cpluslib/buffer.h"
#include "util/answer.h"

class GResultFile;
class Directory;
class AnswerProvider;

class GUnpacker : public GGameDirManipulator {
 public:
    enum Format {
        WindowsFormat,
        DosFormat
    };
    enum {
        qAcceptRaceNames
    };

    GUnpacker();
    ~GUnpacker();

    void setFormat(Format fmt);
    void setIgnore35Part(bool flag);
    void setCreateTargetExt(bool flag);
    void setFixErrors(bool flag);
    void setForceIgnoreErrors(bool flag);
    void setAnswerProvider(AnswerProvider& ap);

    void unpack(GResultFile& result, int player);

 private:
    Format opt_format;          ///< Format of directory to create.
    bool   opt_ignore_35;       ///< true to ignore 3.5 part of RST.
    bool   opt_target_ext;      ///< true to generate TARGETx.EXT file.
    bool   opt_errors;          ///< true to fix some errors.
    bool   opt_force;           ///< true to unpack despite checksum errors.

    AnswerProvider* opt_answer; ///< Answer provider.

    GGen   gen;
    Buffer<char> target_ext_buffer;

    void unpackShips(GResultFile& result, int player);
    void unpackPlanets(GResultFile& result, int player);
    void unpackBases(GResultFile& result, int player);
    void unpackTargets(GResultFile& result, int player);
    void unpackVCRs(GResultFile& result, int player);
    void unpackShipXY(GResultFile& result, int player, int32 space);
    void unpackMessages(GResultFile& result, int player);
    void unpackKore(GResultFile& result, int player);
    void unpackSkore(GResultFile& result, int player);

    void createBlankFiles(int player);

    void saveGen(int player);
    void saveTargetExt(int player);

    void copyAndFix(TShip& dat, TShip& dis);
    void copyAndFix(TPlanet& dat, TPlanet& dis);
    void copyAndFix(TStarbase& dat, TStarbase& dis);

    void updateIndex(int player);
};

#endif
