/**
  *  \file int/names.h
  *  \brief Interpreter: Variable Name Mapping
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_INT_NAMES_H
#define PCC_V2_INT_NAMES_H

#include <vector>
#include "cpluslib/types.h"
#include "cpluslib/string.h"

class Stream;

/** Variable Name Mapping. This provides a mapping from variable names to
    addresses (IntDataSegment indices) and back.

    Names are stored in a vector. In a separate vector, we store hash
    bucket numbers and link information. The hash produces about 1/6
    overall speedup. */
class IntVariableNames {
    IntVariableNames& operator=(const IntVariableNames&);

    std::vector<string_t> names;

    std::vector<int32_t> hashFirst;
    std::vector<int32_t> hashNext;
 public:
    typedef int32_t index_t;

    static const index_t nil = -1;

    // default IntVariableNames(const IntVariableNames&);
    IntVariableNames();
    ~IntVariableNames();

    index_t  lookup(const string_t& name) const;
    index_t  add(const string_t& name);
    index_t  addMaybe(const string_t& name);
    const string_t& lookupAddress(index_t index) const;
    index_t  getNumNames() const;

    void     save(Stream& s, uint32_t count) const;
    void     load(Stream& s, uint32_t count);
};

/** Look up address.
    \param index Index (address), must exist
    \return Associated name
    \pre index < getNumNames() */
inline const string_t&
IntVariableNames::lookupAddress(index_t index) const
{
    return names[index];
}

/** Get number of names. */
inline IntVariableNames::index_t
IntVariableNames::getNumNames() const
{
    return names.size();
}

#endif
