/**
  *  \file reshack/grid.h
  *  \brief Resource Editor: Grid Widgets
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_RESHACK_GRID_H
#define PCC_V2_RESHACK_GRID_H

#include <vector>
#include "ui/widgets/icongrid.h"

class GfxBitmapFont;

/** Character grid. Displays characters from a font and allows
    selecting one.

    This widget displays lines containing 8, 16 or 32 characters each. 
    Characters which don't have a glyph are displayed using a
    placeholder. Sequences of empty lines are compressed down to just
    one empty line. */
class RHCharacterGrid : public UIIconGrid {
    /** First codepoint for each line. */
    std::vector<uint16_t> firsts;

    /** Font to display. */
    const GfxBitmapFont& font;

    void init();
 public:
    RHCharacterGrid(const GfxBitmapFont& font, int id = 0);
    ~RHCharacterGrid();

    uint32_t getCurrentCharacter();
    void setCurrentCharacter(uint32_t n);

    void drawIcon(GfxCanvas& can, const GfxRect& pos, int x, int y, FocusState state);
};

#endif
